==> fwdi-0.0.2.tar.gz: fwdi-0.0.2/fwdi/Presentation/DefaultControllers/home_controller.py <==
#        _       __        __    __________    _____     __   __     __
#   	/ \	    |  |	  |__|  |__________|  |  _  \   |__|  \ \   / /
#      / _ \	|  |	   __       |  |      | |_)  |   __    \ \_/ /   Alitrix - Modern NLP
#     / /_\ \	|  |	  |  |      |  |      |  _  /   |  |    } _ {    Languages: Python, C#
#    / _____ \	|  |____  |  |      |  |      | | \ \   |  |   / / \ \   http://github.com/Alitrix
#   /_/     \_\	|_______| |__|	    |__|      |_|  \_\  |__|  /_/   \_\

# Licensed under the MIT License <http://opensource.org/licenses/MIT>
# SPDX-License-Identifier: MIT
# Copyright (c) 2020-2021 The Alitrix Authors <http://github.com/Alitrix>
from datetime import datetime
from fastapi import Response

from ...Abstractions.meta_service import MetaService
from ...Abstractions.base_controller import BaseController

class Controller(metaclass=MetaService):
    def __init__(self):
        super().__init__()
        self.type_page = "application/xml"
        self.default_page = """
#        _       __        __    __________    _____     __   __     __
#   	/ \	    |  |	  |__|  |__________|  |  _  \   |__|  \ \   / /
#      / _ \	|  |	   __       |  |      | |_)  |   __    \ \_/ /   Alitrix - Modern NLP
#     / /_\ \	|  |	  |  |      |  |      |  _  /   |  |    } _ {    Languages: Python, C#
#    / _____ \	|  |____  |  |      |  |      | | \ \   |  |   / / \ \   http://github.com/Alitrix
#   /_/     \_\	|_______| |__|	    |__|      |_|  \_\  |__|  /_/   \_\
"""
    def index(self, name:str="User"):
        page = f"{self.default_page}\n\t\tHello {name} !!! {datetime.now()}" if len(name) > 0 else self.default_page
        return Response(content=page, media_type=self.type_page) # HTMLResponse(content=demo, status_code=200)

==> fwdi-0.0.83.tar.gz: fwdi-0.0.83/fwdi/Presentation/DefaultControllers/home_controller.py <==
#        _       __        __    __________    _____     __   __     __
#   	/ \	    |  |	  |__|  |__________|  |  _  \   |__|  \ \   / /
#      / _ \	|  |	   __       |  |      | |_)  |   __    \ \_/ /   Alitrix - Modern NLP
#     / /_\ \	|  |	  |  |      |  |      |  _  /   |  |    } _ {    Languages: Python, C#
#    / _____ \	|  |____  |  |      |  |      | | \ \   |  |   / / \ \   http://github.com/Alitrix
#   /_/     \_\	|_______| |__|	    |__|      |_|  \_\  |__|  /_/   \_\

# Licensed under the MIT License <http://opensource.org/licenses/MIT>
# SPDX-License-Identifier: MIT
# Copyright (c) 2020-2021 The Alitrix Authors <http://github.com/Alitrix>
from datetime import datetime
from fastapi import Response

from ...Application.Abstractions.meta_service import MetaServiceFWDI

class Controller(metaclass=MetaServiceFWDI):
    def __init__(self):
        super().__init__()
        self.type_page = "application/xml"
        self.default_page = """
#        _       __        __    __________    _____     __   __     __
#   	/ \	    |  |	  |__|  |__________|  |  _  \   |__|  \ \   / /
#      / _ \	|  |	   __       |  |      | |_)  |   __    \ \_/ /   Alitrix - Modern NLP
#     / /_\ \	|  |	  |  |      |  |      |  _  /   |  |    } _ {    Languages: Python, C#
#    / _____ \	|  |____  |  |      |  |      | | \ \   |  |   / / \ \   http://github.com/Alitrix
#   /_/     \_\	|_______| |__|	    |__|      |_|  \_\  |__|  /_/   \_\
"""
    def index(self, message:str)->Response:
        Controller.__log__(f"{__name__}:{message}")
        page = f"{self.default_page}\n\t\tHello {message} !!! {datetime.now()}" if len(message) > 0 else self.default_page
        return Response(content=page, media_type=self.type_page) # HTMLResponse(content=demo, status_code=200)
